.. _all-salt.clouds:

=============
cloud modules
=============

.. currentmodule:: salt.cloud.clouds

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    aliyun
    clc
    cloudstack
    digitalocean
    dimensiondata
    ec2
    gce
    gogrid
    hetzner
    joyent
    libvirt
    linode
    lxc
    oneandone
    opennebula
    openstack
    packet
    parallels
    profitbricks
    proxmox
    pyrax
    qingcloud
    saltify
    scaleway
    softlayer
    softlayer_hw
    tencentcloud
    vagrant
    virtualbox
    vmware
    vultrpy
    xen
